pub unsafe trait FilelikeViewType: FromFilelike + IntoFilelike { }Expand description
Declare that a type is safe to use in a FilelikeView.
Safety
Types implementing this trait declare that if they are constructed with
FromFilelike and consumed with IntoFilelike, their IntoFilelike
will return the same OwnedFd value that was passed to their
FromFilelike.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
impl FilelikeViewType for File
Implementors
impl FilelikeViewType for OwnedFd
Available on Unix or WASI or HermitCore only.