pub unsafe trait SocketlikeViewType: FromSocketlike + IntoSocketlike { }Expand description
Declare that a type is safe to use in a SocketlikeView.
Safety
Types implementing this trait declare that if they are constructed with
FromSocketlike and consumed with IntoSocketlike, their
IntoSocketlike will return the same OwnedFd value that was passed to
their FromSocketlike.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
impl SocketlikeViewType for TcpListener
impl SocketlikeViewType for TcpStream
impl SocketlikeViewType for UdpSocket
impl SocketlikeViewType for UnixDatagram
Available on Unix only.
impl SocketlikeViewType for UnixListener
Available on Unix only.
impl SocketlikeViewType for UnixStream
Available on Unix only.